Index: trunk/ICeCoffEE/ICeCoffEE/APEMain.m
===================================================================
--- trunk/ICeCoffEE/ICeCoffEE/APEMain.m	(revision 82)
+++ trunk/ICeCoffEE/ICeCoffEE/APEMain.m	(revision 88)
@@ -18,4 +18,5 @@
 #import "ICeCoffEE.h"
 #import "ICeCoffEETextEdit.h"
+#import "CPS.h"
 
 //¥¥¥ Our settings
@@ -77,4 +78,23 @@
     {
         ICapeprintf("ICeCoffEE APE: not loading as this application is excluded.\n");
+        return;
+    }
+
+    CPSProcessSerNum psn;
+    OSStatus err = CPSGetCurrentProcess(&psn);
+    if (err != noErr) {
+        apeprintf("ICeCoffEE APE: Can't get process serial number for current process (error %ld); not loading in this application\n", err);
+        return;
+    }
+    
+    CPSProcessInfoRec info;
+    err = CPSGetProcessInfo(&psn, &info, NULL, 0, NULL, NULL, 0);
+    if (err != noErr) {
+        apeprintf("ICeCoffEE APE: Can't get process information (error %ld); not loading in this application\n", err);
+        return;
+    }
+    ICapeprintf("ICeCoffEE APE: got process attributes = 0x%lx\n", info.Attributes);
+    if (info.Attributes & (kCPSBGOnlyAttr | kCPSUIElementAttr | kCPSFullScreenAttr)) {
+        ICapeprintf("ICeCoffEE APE: not loading as this application is background-only\n");
         return;
     }
Index: trunk/ICeCoffEE/ICeCoffEE/CPS.h
===================================================================
--- trunk/ICeCoffEE/ICeCoffEE/CPS.h	(revision 88)
+++ trunk/ICeCoffEE/ICeCoffEE/CPS.h	(revision 88)
@@ -0,0 +1,299 @@
+// CPS.h
+
+#pragma once
+
+#include <ApplicationServices/ApplicationServices.h>
+
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+#if PRAGMA_STRUCT_ALIGN
+    #pragma options align=mac68k
+#elif PRAGMA_STRUCT_PACKPUSH
+    #pragma pack(push, 2)
+#elif PRAGMA_STRUCT_PACK
+    #pragma pack(2)
+#endif
+
+
+struct CPSProcessSerNum
+{
+	UInt32		lo;
+	UInt32		hi;
+};
+
+typedef struct CPSProcessSerNum	CPSProcessSerNum;
+
+enum
+{
+	kCPSNoProcess		=	0,
+	kCPSSystemProcess	=	1,
+	kCPSCurrentProcess	=	2
+};
+
+
+enum
+{
+	bfCPSIntraProcessSwitch =	1,
+	bfCPSDeathBySignal	=	2
+};
+
+typedef UInt16	CPSEventFlags;
+
+
+enum
+{
+	kCPSBlueApp	=	0,
+	kCPSBlueBox	=	1,
+	kCPSCarbonApp	=	2,
+	kCPSYellowApp	=	3,
+	kCPSUnknownApp	=	4
+};
+
+typedef UInt32	CPSAppFlavour;
+
+
+enum
+{
+	kCPSBGOnlyAttr		=	1024,
+	kCPSUIElementAttr	=	65536,
+	kCPSHiddenAttr		=	131072,
+	kCPSNoConnectAttr	=	262144,
+	kCPSFullScreenAttr	=	524288,
+	kCPSClassicReqAttr	=	1048576,
+	kCPSNativeReqAttr	=	2097152
+};
+
+typedef UInt32	CPSProcAttributes;
+
+
+struct CPSProcessInfoRec
+{
+	CPSProcessSerNum 	Parent;
+	UInt64			LaunchDate;
+	CPSAppFlavour		Flavour;
+	CPSProcAttributes	Attributes;
+	UInt32			ExecFileType;
+	UInt32			ExecFileCreator;
+	UInt32			UnixPID;
+};
+
+typedef struct CPSProcessInfoRec	CPSProcessInfoRec;
+
+
+enum
+{
+	kCPSNotifyChildDeath	=	1,
+	kCPSNotifyNewFront	=	2,
+	kCPSNotifyAppBirth	=	4,
+	kCPSNotifyAppDeath	=	8,
+	kCPSNotifyLaunch	=	9,
+	kCPSNotifyServiceReq	=	16,
+	kCPSNotifyAppHidden	=	32,
+	kCPSNotifyAppRevealed	=	64,
+	kCPSNotifyFGEnabled	=	128,
+	kCPSNotifyLaunchStart	=	256,
+	kCPSNotifyAppReady	=	512,
+	kCPSNotifyLaunchFail	=	1024,
+	kCPSNotifyAppDeathExt	=	2048,
+	kCPSNotifyLostKeyFocus	=	4096
+};
+
+typedef UInt32	CPSNotificationCodes;
+
+
+enum
+{
+	bfCPSLaunchInhibitDaemon	=	128,
+	bfCPSLaunchDontSwitch		=	512,
+	bfCPSLaunchNoProcAttr		=	2048,
+	bfCPSLaunchAsync		=	65536,
+	bfCPSLaunchStartClassic		=	131072,
+	bfCPSLaunchInClassic		=	262144,
+	bfCPSLaunchInstance		=	524288,
+	bfCPSLaunchAndHide		=	1048576,
+	bfCPSLaunchAndHideOthers	=	2097152
+};
+
+typedef UInt32	CPSLaunchOptions;
+
+
+typedef	UInt8	*CPSLaunchRefcon;
+
+
+typedef	UInt8	*CPSLaunchData;
+
+
+enum
+{
+	bfCPSExtLaunchWithData	=	2,
+	bfCPSExtLaunchByParent	=	4,
+	bfCPSExtLaunchAsUidGid	=	8
+};
+
+typedef UInt32	CPSLaunchPBFields;
+
+
+struct CPSLaunchPB
+{
+	CPSLaunchPBFields	Contents;
+	CPSLaunchData		pData;
+	UInt32			DataLen;
+	UInt32			DataTag;
+	UInt32			RefCon;
+	CPSProcessSerNum	Parent;
+	UInt32			ChildUID;
+	UInt32			ChildGID;
+};
+
+typedef struct CPSLaunchPB	CPSLaunchPB;
+
+
+enum
+{
+	bfCPSKillHard		=	1,
+	bfCPSKillAllClassicApps	=	2
+};
+
+typedef UInt32	CPSKillOptions;
+
+
+enum
+{
+	kCPSLaunchService	=	0,
+	kCPSKillService		=	1,
+	kCPSHideService		=	2,
+	kCPSShowService		=	3,
+	kCPSPrivService		=	4,
+	kCPSExtDeathNoteService	=	5
+};
+
+typedef UInt32	CPSServiceReqType;
+
+
+struct CPSLaunchRequest
+{
+	CPSProcessSerNum	TargetPSN;
+	CPSLaunchOptions 	Options;
+	CPSProcAttributes 	ProcAttributes;
+	UInt8			*pUTF8TargetPath;
+	UInt32			PathLen;
+};
+
+typedef struct CPSLaunchRequest	CPSLaunchRequest;
+
+
+struct CPSKillRequest
+{
+	CPSProcessSerNum	TargetPSN;
+	CPSKillOptions		Options;
+};
+
+typedef struct CPSKillRequest	CPSKillRequest;
+
+
+struct CPSHideRequest
+{
+	CPSProcessSerNum 	TargetPSN;
+};
+
+typedef struct CPSHideRequest	CPSHideRequest;
+
+
+struct CPSShowRequest
+{
+	CPSProcessSerNum 	TargetPSN;
+};
+
+typedef struct CPSShowRequest	CPSShowRequest;
+
+
+struct CPSExtDeathNotice
+{
+	CPSProcessSerNum 	DeadPSN;
+	UInt32			Flags;
+	UInt8			*pUTF8AppPath;
+	UInt32			PathLen;
+};
+
+typedef struct CPSExtDeathNotice	CPSExtDeathNotice;
+
+
+union CPSRequestDetails
+{
+	CPSLaunchRequest 	LaunchReq;
+	CPSKillRequest 		KillReq;
+	CPSHideRequest 		HideReq;
+	CPSShowRequest 		ShowReq;
+	CPSExtDeathNotice 	DeathNotice;
+};
+
+typedef union CPSRequestDetails	CPSRequestDetails;
+
+
+struct CPSServiceRequest
+{
+	CPSServiceReqType 	Type;
+	SInt32			ID;
+	CPSRequestDetails 	Details;
+};
+
+typedef struct CPSServiceRequest	CPSServiceRequest;
+
+
+enum
+{
+	kCPSProcessInterruptKey	=	0,
+	kCPSAppSwitchFwdKey	=	1,
+	kCPSAppSwitchBackKey	=	2,
+	kCPSSessionInterruptKey	=	3,
+	kCPSScreenSaverKey	=	4,
+	kCPSDiskEjectKey	=	5,
+	kCPSSpecialKeyCount	=	6
+};
+
+typedef SInt32	CPSSpecialKeyID;
+
+
+extern Boolean	CPSEqualProcess( CPSProcessSerNum *psn1, CPSProcessSerNum *psn2);
+
+extern OSErr	CPSGetCurrentProcess( CPSProcessSerNum *psn);
+
+extern OSErr	CPSGetFrontProcess( CPSProcessSerNum *psn);
+
+extern OSErr	CPSGetNextProcess( CPSProcessSerNum *psn);
+
+extern OSErr	CPSGetNextToFrontProcess( CPSProcessSerNum *psn);
+
+extern OSErr	CPSGetProcessInfo( CPSProcessSerNum *psn, CPSProcessInfoRec *info, char *path, int maxPathLen, int *len, char *name, int maxNameLen);
+
+extern OSErr	CPSPostHideMostReq( CPSProcessSerNum *psn);
+
+extern OSErr	CPSPostHideReq( CPSProcessSerNum *psn);
+
+extern OSErr	CPSPostKillRequest( CPSProcessSerNum *psn, CPSKillOptions options);
+
+extern OSErr	CPSPostShowAllReq( CPSProcessSerNum *psn);
+
+extern OSErr	CPSPostShowReq( CPSProcessSerNum *psn);
+
+extern OSErr	CPSSetFrontProcess( CPSProcessSerNum *psn);
+
+extern OSErr	CPSReleaseKeyFocus( CPSProcessSerNum *psn);
+
+extern OSErr	CPSStealKeyFocus( CPSProcessSerNum *psn);
+
+
+#if PRAGMA_STRUCT_ALIGN
+    #pragma options align=reset
+#elif PRAGMA_STRUCT_PACKPUSH
+    #pragma pack(pop)
+#elif PRAGMA_STRUCT_PACK
+    #pragma pack()
+#endif
+
+#ifdef __cplusplus
+}
+#endif
Index: trunk/ICeCoffEE/ICeCoffEE/ICeCoffEE APE.pbproj/nicholas.pbxuser
===================================================================
--- trunk/ICeCoffEE/ICeCoffEE/ICeCoffEE APE.pbproj/nicholas.pbxuser	(revision 82)
+++ trunk/ICeCoffEE/ICeCoffEE/ICeCoffEE APE.pbproj/nicholas.pbxuser	(revision 88)
@@ -23,5 +23,5 @@
 		);
 		perUserDictionary = {
-			PBXPerProjectTemplateStateSaveDate = 65919668;
+			PBXPerProjectTemplateStateSaveDate = 66254177;
 			PBXWorkspaceContents = (
 				{
@@ -30,19 +30,40 @@
 							Split0 = {
 								NavContent0 = {
-									bookmark = E120348F03EDEBC100000ABE;
+									bookmark = E166E9B303F2F8F100050002;
 									history = (
-										E120347903EDEBC100000ABE,
 										E120347A03EDEBC100000ABE,
 										E120347B03EDEBC100000ABE,
-										E120347C03EDEBC100000ABE,
+										E120347E03EDEBC100000ABE,
+										E120348003EDEBC100000ABE,
+										E11854FA03F27D4A00050002,
+										E11854FB03F27D4A00050002,
+										E11854FC03F27D4A00050002,
+										E11854FD03F27D4A00050002,
+										E11854FE03F27D4A00050002,
+										E11854FF03F27D4A00050002,
+										E118550003F27D4A00050002,
+										E118550103F27D4A00050002,
+										E118550203F27D4A00050002,
+										E118550303F27D4A00050002,
+										E118550403F27D4A00050002,
+										E118550503F27D4A00050002,
+										E118550603F27D4A00050002,
+										E118550703F27D4A00050002,
+										E118550803F27D4A00050002,
+										E118550903F27D4A00050002,
+										E118550A03F27D4A00050002,
+										E118550B03F27D4A00050002,
+										E118550C03F27D4A00050002,
+										E118550D03F27D4A00050002,
+										E118550E03F27D4A00050002,
+										E118550F03F27D4A00050002,
+										E118551003F27D4A00050002,
+										E118551103F27D4A00050002,
+										E166E9A903F2F8F100050002,
+										E166E9AA03F2F8F100050002,
+										E166E9AB03F2F8F100050002,
+										E166E9AC03F2F8F100050002,
+										E166E9AD03F2F8F100050002,
 										E120347D03EDEBC100000ABE,
-										E120347E03EDEBC100000ABE,
-										E120347F03EDEBC100000ABE,
-										E120348003EDEBC100000ABE,
-										E120348103EDEBC100000ABE,
-										E120348203EDEBC100000ABE,
-									);
-									nextStack = (
-										E120348E03EDEBC100000ABE,
 									);
 									prevStack = (
@@ -58,9 +79,49 @@
 										E120348C03EDEBC100000ABE,
 										E120348D03EDEBC100000ABE,
+										E157EE6C03F059E300050002,
+										E157EE6D03F059E300050002,
+										E157EE6E03F059E300050002,
+										E157EE6F03F059E300050002,
+										E118551303F27D4A00050002,
+										E118551403F27D4A00050002,
+										E118551503F27D4A00050002,
+										E118551603F27D4A00050002,
+										E118551703F27D4A00050002,
+										E118551803F27D4A00050002,
+										E118551903F27D4A00050002,
+										E118551A03F27D4A00050002,
+										E118551B03F27D4A00050002,
+										E118551C03F27D4A00050002,
+										E118551D03F27D4A00050002,
+										E118551E03F27D4A00050002,
+										E118551F03F27D4A00050002,
+										E118552003F27D4A00050002,
+										E118552103F27D4A00050002,
+										E118552203F27D4A00050002,
+										E118552303F27D4A00050002,
+										E118552403F27D4A00050002,
+										E118552503F27D4A00050002,
+										E118552603F27D4A00050002,
+										E118552703F27D4A00050002,
+										E118552803F27D4A00050002,
+										E118552903F27D4A00050002,
+										E118552A03F27D4A00050002,
+										E118552B03F27D4A00050002,
+										E118552C03F27D4A00050002,
+										E118552D03F27D4A00050002,
+										E118552E03F27D4A00050002,
+										E118552F03F27D4A00050002,
+										E118553003F27D4A00050002,
+										E118553103F27D4A00050002,
+										E166E9AE03F2F8F100050002,
+										E166E9AF03F2F8F100050002,
+										E166E9B003F2F8F100050002,
+										E166E9B103F2F8F100050002,
+										E166E9B203F2F8F100050002,
 									);
 								};
 								NavCount = 1;
 								NavGeometry0 = {
-									Frame = "{{0, 0}, {571, 548}}";
+									Frame = "{{0, 0}, {642, 698}}";
 									NavBarVisible = YES;
 								};
@@ -167,15 +228,15 @@
 			PBXWorkspaceGeometries = (
 				{
-					ContentSize = "{855, 571}";
+					ContentSize = "{925, 721}";
 					LeftSlideOut = {
 						ActiveTab = 0;
 						ActiveTabName = PBXGroupTreeModule;
 						Collapsed = NO;
-						Frame = "{{0, 23}, {855, 548}}";
+						Frame = "{{0, 23}, {925, 698}}";
 						Split0 = {
 							Collapsed = NO;
-							Frame = "{{284, 0}, {571, 548}}";
+							Frame = "{{283, 0}, {642, 698}}";
 							Split0 = {
-								Frame = "{{0, 0}, {571, 548}}";
+								Frame = "{{0, 0}, {642, 698}}";
 							};
 							SplitCount = 1;
@@ -239,10 +300,10 @@
 						SplitCount = 1;
 						Tab0 = {
-							Frame = "{{0, 0}, {260, 548}}";
+							Frame = "{{0, 0}, {259, 698}}";
 							GroupTreeTableConfiguration = (
 								TargetStatusColumn,
 								18,
 								MainColumn,
-								227,
+								226,
 							);
 						};
@@ -292,5 +353,5 @@
 					Template = 64ABBB4501FA494900185B06;
 					ToolbarVisible = YES;
-					WindowLocation = "{2, 198}";
+					WindowLocation = "{2, 48}";
 				},
 				{
@@ -420,5 +481,5 @@
 					Template = F5314676015831810DCA290F;
 					ToolbarVisible = YES;
-					WindowLocation = "{509, 82}";
+					WindowLocation = "{508, 82}";
 				},
 				{
@@ -433,5 +494,5 @@
 							Frame = "{{0, 0}, {594, 280}}";
 							Split0 = {
-								Frame = "{{1e+06, 1e+06}, {594, 27}}";
+								Frame = "{{1e+06, 1e+06}, {594, 0}}";
 							};
 							SplitCount = 1;
@@ -548,20 +609,70 @@
 					Template = F5534CB2020F3F8A0DCA290F;
 					ToolbarVisible = YES;
-					WindowLocation = "{4, 467}";
+					WindowLocation = "{488, 121}";
 				},
 			);
-			PBXWorkspaceStateSaveDate = 65919668;
+			PBXWorkspaceStateSaveDate = 66254177;
 		};
 		perUserProjectItems = {
-			E120347903EDEBC100000ABE = E120347903EDEBC100000ABE;
+			E11854FA03F27D4A00050002 = E11854FA03F27D4A00050002;
+			E11854FB03F27D4A00050002 = E11854FB03F27D4A00050002;
+			E11854FC03F27D4A00050002 = E11854FC03F27D4A00050002;
+			E11854FD03F27D4A00050002 = E11854FD03F27D4A00050002;
+			E11854FE03F27D4A00050002 = E11854FE03F27D4A00050002;
+			E11854FF03F27D4A00050002 = E11854FF03F27D4A00050002;
+			E118550003F27D4A00050002 = E118550003F27D4A00050002;
+			E118550103F27D4A00050002 = E118550103F27D4A00050002;
+			E118550203F27D4A00050002 = E118550203F27D4A00050002;
+			E118550303F27D4A00050002 = E118550303F27D4A00050002;
+			E118550403F27D4A00050002 = E118550403F27D4A00050002;
+			E118550503F27D4A00050002 = E118550503F27D4A00050002;
+			E118550603F27D4A00050002 = E118550603F27D4A00050002;
+			E118550703F27D4A00050002 = E118550703F27D4A00050002;
+			E118550803F27D4A00050002 = E118550803F27D4A00050002;
+			E118550903F27D4A00050002 = E118550903F27D4A00050002;
+			E118550A03F27D4A00050002 = E118550A03F27D4A00050002;
+			E118550B03F27D4A00050002 = E118550B03F27D4A00050002;
+			E118550C03F27D4A00050002 = E118550C03F27D4A00050002;
+			E118550D03F27D4A00050002 = E118550D03F27D4A00050002;
+			E118550E03F27D4A00050002 = E118550E03F27D4A00050002;
+			E118550F03F27D4A00050002 = E118550F03F27D4A00050002;
+			E118551003F27D4A00050002 = E118551003F27D4A00050002;
+			E118551103F27D4A00050002 = E118551103F27D4A00050002;
+			E118551303F27D4A00050002 = E118551303F27D4A00050002;
+			E118551403F27D4A00050002 = E118551403F27D4A00050002;
+			E118551503F27D4A00050002 = E118551503F27D4A00050002;
+			E118551603F27D4A00050002 = E118551603F27D4A00050002;
+			E118551703F27D4A00050002 = E118551703F27D4A00050002;
+			E118551803F27D4A00050002 = E118551803F27D4A00050002;
+			E118551903F27D4A00050002 = E118551903F27D4A00050002;
+			E118551A03F27D4A00050002 = E118551A03F27D4A00050002;
+			E118551B03F27D4A00050002 = E118551B03F27D4A00050002;
+			E118551C03F27D4A00050002 = E118551C03F27D4A00050002;
+			E118551D03F27D4A00050002 = E118551D03F27D4A00050002;
+			E118551E03F27D4A00050002 = E118551E03F27D4A00050002;
+			E118551F03F27D4A00050002 = E118551F03F27D4A00050002;
+			E118552003F27D4A00050002 = E118552003F27D4A00050002;
+			E118552103F27D4A00050002 = E118552103F27D4A00050002;
+			E118552203F27D4A00050002 = E118552203F27D4A00050002;
+			E118552303F27D4A00050002 = E118552303F27D4A00050002;
+			E118552403F27D4A00050002 = E118552403F27D4A00050002;
+			E118552503F27D4A00050002 = E118552503F27D4A00050002;
+			E118552603F27D4A00050002 = E118552603F27D4A00050002;
+			E118552703F27D4A00050002 = E118552703F27D4A00050002;
+			E118552803F27D4A00050002 = E118552803F27D4A00050002;
+			E118552903F27D4A00050002 = E118552903F27D4A00050002;
+			E118552A03F27D4A00050002 = E118552A03F27D4A00050002;
+			E118552B03F27D4A00050002 = E118552B03F27D4A00050002;
+			E118552C03F27D4A00050002 = E118552C03F27D4A00050002;
+			E118552D03F27D4A00050002 = E118552D03F27D4A00050002;
+			E118552E03F27D4A00050002 = E118552E03F27D4A00050002;
+			E118552F03F27D4A00050002 = E118552F03F27D4A00050002;
+			E118553003F27D4A00050002 = E118553003F27D4A00050002;
+			E118553103F27D4A00050002 = E118553103F27D4A00050002;
 			E120347A03EDEBC100000ABE = E120347A03EDEBC100000ABE;
 			E120347B03EDEBC100000ABE = E120347B03EDEBC100000ABE;
-			E120347C03EDEBC100000ABE = E120347C03EDEBC100000ABE;
 			E120347D03EDEBC100000ABE = E120347D03EDEBC100000ABE;
 			E120347E03EDEBC100000ABE = E120347E03EDEBC100000ABE;
-			E120347F03EDEBC100000ABE = E120347F03EDEBC100000ABE;
 			E120348003EDEBC100000ABE = E120348003EDEBC100000ABE;
-			E120348103EDEBC100000ABE = E120348103EDEBC100000ABE;
-			E120348203EDEBC100000ABE = E120348203EDEBC100000ABE;
 			E120348303EDEBC100000ABE = E120348303EDEBC100000ABE;
 			E120348403EDEBC100000ABE = E120348403EDEBC100000ABE;
@@ -575,6 +686,19 @@
 			E120348C03EDEBC100000ABE = E120348C03EDEBC100000ABE;
 			E120348D03EDEBC100000ABE = E120348D03EDEBC100000ABE;
-			E120348E03EDEBC100000ABE = E120348E03EDEBC100000ABE;
-			E120348F03EDEBC100000ABE = E120348F03EDEBC100000ABE;
+			E157EE6C03F059E300050002 = E157EE6C03F059E300050002;
+			E157EE6D03F059E300050002 = E157EE6D03F059E300050002;
+			E157EE6E03F059E300050002 = E157EE6E03F059E300050002;
+			E157EE6F03F059E300050002 = E157EE6F03F059E300050002;
+			E166E9A903F2F8F100050002 = E166E9A903F2F8F100050002;
+			E166E9AA03F2F8F100050002 = E166E9AA03F2F8F100050002;
+			E166E9AB03F2F8F100050002 = E166E9AB03F2F8F100050002;
+			E166E9AC03F2F8F100050002 = E166E9AC03F2F8F100050002;
+			E166E9AD03F2F8F100050002 = E166E9AD03F2F8F100050002;
+			E166E9AE03F2F8F100050002 = E166E9AE03F2F8F100050002;
+			E166E9AF03F2F8F100050002 = E166E9AF03F2F8F100050002;
+			E166E9B003F2F8F100050002 = E166E9B003F2F8F100050002;
+			E166E9B103F2F8F100050002 = E166E9B103F2F8F100050002;
+			E166E9B203F2F8F100050002 = E166E9B203F2F8F100050002;
+			E166E9B303F2F8F100050002 = E166E9B303F2F8F100050002;
 		};
 		projectwideBuildSettings = {
@@ -584,13 +708,662 @@
 		wantsSCM = -1;
 	};
-	E120347903EDEBC100000ABE = {
+	E11854FA03F27D4A00050002 = {
+		fRef = E169DBA103E4EF5E00050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEETextEdit.c: 24";
+		rLen = 0;
+		rLoc = 708;
+		rType = 0;
+		vrLen = 1370;
+		vrLoc = 0;
+	};
+	E11854FB03F27D4A00050002 = {
+		fRef = E118554503F27D4A00050002;
+		glyphRangeLength = 1141;
+		glyphRangeLocation = 6672;
+		isa = PBXDocBookmark;
+		name = "Editing_Data.html: boundary but...";
+	};
+	E11854FC03F27D4A00050002 = {
+		fRef = E118554603F27D4A00050002;
+		isa = PBXTextBookmark;
+		name = "MacTextEditor.h: 2223";
+		rLen = 0;
+		rLoc = 77465;
+		rType = 0;
+		vrLen = 1220;
+		vrLoc = 76924;
+	};
+	E11854FD03F27D4A00050002 = {
+		fRef = E118554703F27D4A00050002;
+		isa = PBXTextBookmark;
+		name = "MacTypes.h: 301";
+		rLen = 3;
+		rLoc = 11959;
+		rType = 0;
+		vrLen = 1556;
+		vrLoc = 10939;
+	};
+	E11854FE03F27D4A00050002 = {
+		fRef = E118554803F27D4A00050002;
+		isa = PBXTextBookmark;
+		name = "CFArray.h: 559";
+		rLen = 73;
+		rLoc = 26275;
+		rType = 0;
+		vrLen = 2097;
+		vrLoc = 25238;
+	};
+	E11854FF03F27D4A00050002 = {
+		fRef = E118554903F27D4A00050002;
+		isa = PBXTextBookmark;
+		name = "MacErrors.h: 70";
+		rLen = 0;
+		rLoc = 2869;
+		rType = 0;
+		vrLen = 3114;
+		vrLoc = 1688;
+	};
+	E118550003F27D4A00050002 = {
+		fRef = E118553803F27D4A00050002;
+		isa = PBXTextBookmark;
+		name = "CFString.h: 329";
+		rLen = 7;
+		rLoc = 16745;
+		rType = 0;
+		vrLen = 2332;
+		vrLoc = 15554;
+	};
+	E118550103F27D4A00050002 = {
+		fRef = E169DBA703E4F6A400050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEEConfig.h: 15";
+		rLen = 0;
+		rLoc = 275;
+		rType = 0;
+		vrLen = 1716;
+		vrLoc = 218;
+	};
+	E118550203F27D4A00050002 = {
+		fRef = E118553A03F27D4A00050002;
+		isa = PBXTextBookmark;
+		name = "CFBase.h: 174";
+		rLen = 56;
+		rLoc = 4344;
+		rType = 0;
+		vrLen = 1961;
+		vrLoc = 4409;
+	};
+	E118550303F27D4A00050002 = {
+		fRef = E118553B03F27D4A00050002;
+		isa = PBXTextBookmark;
+		name = "CFDictionary.h: 630";
+		rLen = 0;
+		rLoc = 31495;
+		rType = 0;
+		vrLen = 2409;
+		vrLoc = 30254;
+	};
+	E118550403F27D4A00050002 = {
+		fRef = E165AB3603E7A7FC00050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEEActionMenu.c: ICCF_AddAppItemTitle";
+		rLen = 0;
+		rLoc = 2806;
+		rType = 0;
+		vrLen = 1689;
+		vrLoc = 3599;
+	};
+	E118550503F27D4A00050002 = {
+		fRef = E135625E03DC9FC200050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEEShared.h: 2";
+		rLen = 17;
+		rLoc = 7;
+		rType = 0;
+		vrLen = 1334;
+		vrLoc = 0;
+	};
+	E118550603F27D4A00050002 = {
+		fRef = E118553C03F27D4A00050002;
+		isa = PBXTextBookmark;
+		name = "Processes.h: 103";
+		rLen = 21;
+		rLoc = 3167;
+		rType = 0;
+		vrLen = 2130;
+		vrLoc = 2876;
+	};
+	E118550703F27D4A00050002 = {
+		fRef = E118553D03F27D4A00050002;
+		glyphRangeLength = 1979;
+		glyphRangeLocation = 3056;
+		isa = PBXDocBookmark;
+		name = "Getting_Proc__Information.html: Get informat...";
+	};
+	E118550803F27D4A00050002 = {
+		fRef = E118553E03F27D4A00050002;
+		glyphRangeLength = 1502;
+		glyphRangeLocation = 0;
+		isa = PBXDocBookmark;
+		name = "ProcessInfoRec.html: PATHDocument...";
+	};
+	E118550903F27D4A00050002 = {
+		fRef = E118553F03F27D4A00050002;
+		glyphRangeLength = 2;
+		glyphRangeLocation = 4;
+		isa = PBXDocBookmark;
+		name = "carbon.html: ...";
+	};
+	E118550A03F27D4A00050002 = {
+		fRef = E118554203F27D4A00050002;
+		glyphRangeLength = 4;
+		glyphRangeLocation = 0;
+		isa = PBXDocBookmark;
+		name = "processmanager.html: ...";
+	};
+	E118550B03F27D4A00050002 = {
+		fRef = E118554303F27D4A00050002;
+		glyphRangeLength = 0;
+		glyphRangeLocation = 0;
+		isa = PBXDocBookmark;
+	};
+	E118550C03F27D4A00050002 = {
 		fRef = E182C8F603DE817F00050002;
 		isa = PBXTextBookmark;
-		name = "ICeCoffEEShared.m: __VERSION__";
+		name = "ICeCoffEEShared.m: 16";
+		rLen = 0;
+		rLoc = 357;
+		rType = 0;
+		vrLen = 1491;
+		vrLoc = 0;
+	};
+	E118550D03F27D4A00050002 = {
+		fRef = E14343B403DB4CF200050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEE.m: __PTRDIFF_TYPE__";
+		rLen = 0;
+		rLoc = 197;
+		rType = 0;
+		vrLen = 1599;
+		vrLoc = 0;
+	};
+	E118550E03F27D4A00050002 = {
+		fRef = E11854F703F2709E00050002;
+		isa = PBXTextBookmark;
+		name = "CPS.h: kCPSUIElementAttr";
+		rLen = 17;
+		rLoc = 742;
+		rType = 0;
+		vrLen = 739;
+		vrLoc = 510;
+	};
+	E118550F03F27D4A00050002 = {
+		fRef = E118554403F27D4A00050002;
+		isa = PBXTextBookmark;
+		name = "LaunchServices.h: 1";
 		rLen = 0;
 		rLoc = 0;
 		rType = 0;
-		vrLen = 1401;
-		vrLoc = 0;
+		vrLen = 1041;
+		vrLoc = 0;
+	};
+	E118551003F27D4A00050002 = {
+		fRef = E118553903F27D4A00050002;
+		isa = PBXTextBookmark;
+		name = "APETools.h: 62";
+		rLen = 82;
+		rLoc = 2811;
+		rType = 0;
+		vrLen = 2318;
+		vrLoc = 1156;
+	};
+	E118551103F27D4A00050002 = {
+		fRef = F9A6986E03BE1DF000AA4DA5;
+		isa = PBXTextBookmark;
+		name = "APEMain.m: APEBundleMain";
+		rLen = 0;
+		rLoc = 2217;
+		rType = 0;
+		vrLen = 1834;
+		vrLoc = 1604;
+	};
+	E118551303F27D4A00050002 = {
+		fRef = F56276C20379923401AA4DA5;
+		isa = PBXTextBookmark;
+		name = "APEInfo.rtfd: 118";
+		rLen = 0;
+		rLoc = 7588;
+		rType = 0;
+		vrLen = 1177;
+		vrLoc = 6919;
+	};
+	E118551403F27D4A00050002 = {
+		fRef = E14343B403DB4CF200050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEE.m: __VERSION__";
+		rLen = 0;
+		rLoc = 0;
+		rType = 0;
+		vrLen = 1134;
+		vrLoc = 0;
+	};
+	E118551503F27D4A00050002 = {
+		fRef = E169DBA103E4EF5E00050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEETextEdit.c: 24";
+		rLen = 0;
+		rLoc = 708;
+		rType = 0;
+		vrLen = 1370;
+		vrLoc = 0;
+	};
+	E118551603F27D4A00050002 = {
+		fRef = E118553303F27D4A00050002;
+		isa = PBXTextBookmark;
+		name = "MacTextEditor.h: 2223";
+		rLen = 0;
+		rLoc = 77465;
+		rType = 0;
+		vrLen = 1220;
+		vrLoc = 76924;
+	};
+	E118551703F27D4A00050002 = {
+		fRef = E165AB3603E7A7FC00050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEEActionMenu.c: ICCF_DoURLActionMenu";
+		rLen = 0;
+		rLoc = 8672;
+		rType = 0;
+		vrLen = 1734;
+		vrLoc = 4975;
+	};
+	E118551803F27D4A00050002 = {
+		fRef = F56276C20379923401AA4DA5;
+		isa = PBXTextBookmark;
+		name = "APEInfo.rtfd: 117";
+		rLen = 0;
+		rLoc = 7520;
+		rType = 0;
+		vrLen = 1583;
+		vrLoc = 6657;
+	};
+	E118551903F27D4A00050002 = {
+		fRef = E165AB3603E7A7FC00050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEEActionMenu.c: ICCF_CompareURLsByItemTitle";
+		rLen = 0;
+		rLoc = 5736;
+		rType = 0;
+		vrLen = 1956;
+		vrLoc = 4897;
+	};
+	E118551A03F27D4A00050002 = {
+		fRef = E169DBA703E4F6A400050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEEConfig.h: 15";
+		rLen = 0;
+		rLoc = 275;
+		rType = 0;
+		vrLen = 1716;
+		vrLoc = 218;
+	};
+	E118551B03F27D4A00050002 = {
+		fRef = E135625E03DC9FC200050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEEShared.h: 2";
+		rLen = 17;
+		rLoc = 7;
+		rType = 0;
+		vrLen = 1334;
+		vrLoc = 0;
+	};
+	E118551C03F27D4A00050002 = {
+		fRef = E165AB3603E7A7FC00050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEEActionMenu.c: ICCF_AddAppItemTitle";
+		rLen = 0;
+		rLoc = 2806;
+		rType = 0;
+		vrLen = 1689;
+		vrLoc = 3599;
+	};
+	E118551D03F27D4A00050002 = {
+		fRef = F56276C20379923401AA4DA5;
+		isa = PBXTextBookmark;
+		name = "APEInfo.rtfd: 117";
+		rLen = 0;
+		rLoc = 7520;
+		rType = 0;
+		vrLen = 2008;
+		vrLoc = 6398;
+	};
+	E118551E03F27D4A00050002 = {
+		fRef = E135625E03DC9FC200050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEEShared.h: 2";
+		rLen = 17;
+		rLoc = 7;
+		rType = 0;
+		vrLen = 1334;
+		vrLoc = 0;
+	};
+	E118551F03F27D4A00050002 = {
+		fRef = E182C8F603DE817F00050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEEShared.m: 16";
+		rLen = 0;
+		rLoc = 357;
+		rType = 0;
+		vrLen = 1491;
+		vrLoc = 0;
+	};
+	E118552003F27D4A00050002 = {
+		fRef = F9A6986E03BE1DF000AA4DA5;
+		isa = PBXTextBookmark;
+		name = "APEMain.m: APEBundleMain";
+		rLen = 23;
+		rLoc = 2460;
+		rType = 0;
+		vrLen = 2104;
+		vrLoc = 2026;
+	};
+	E118552103F27D4A00050002 = {
+		fRef = E118554A03F27D4A00050002;
+		isa = PBXTextBookmark;
+		name = "APETools.h: 59";
+		rLen = 0;
+		rLoc = 2551;
+		rType = 0;
+		vrLen = 2564;
+		vrLoc = 876;
+	};
+	E118552203F27D4A00050002 = {
+		fRef = E135625E03DC9FC200050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEEShared.h: 2";
+		rLen = 17;
+		rLoc = 7;
+		rType = 0;
+		vrLen = 1334;
+		vrLoc = 0;
+	};
+	E118552303F27D4A00050002 = {
+		fRef = E182C8F603DE817F00050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEEShared.m: 16";
+		rLen = 0;
+		rLoc = 357;
+		rType = 0;
+		vrLen = 1491;
+		vrLoc = 0;
+	};
+	E118552403F27D4A00050002 = {
+		fRef = F9A6986E03BE1DF000AA4DA5;
+		isa = PBXTextBookmark;
+		name = "APEMain.m: ICCF_ReloadPrefs";
+		rLen = 0;
+		rLoc = 11233;
+		rType = 0;
+		vrLen = 1497;
+		vrLoc = 0;
+	};
+	E118552503F27D4A00050002 = {
+		fRef = E118553603F27D4A00050002;
+		isa = PBXTextBookmark;
+		name = "Processes.h: 103";
+		rLen = 21;
+		rLoc = 3167;
+		rType = 0;
+		vrLen = 2130;
+		vrLoc = 2876;
+	};
+	E118552603F27D4A00050002 = {
+		fRef = E118554103F27D4A00050002;
+		glyphRangeLength = 1979;
+		glyphRangeLocation = 3056;
+		isa = PBXDocBookmark;
+		name = "Getting_Proc__Information.html: Get informat...";
+	};
+	E118552703F27D4A00050002 = {
+		fRef = E118553703F27D4A00050002;
+		glyphRangeLength = 1502;
+		glyphRangeLocation = 0;
+		isa = PBXDocBookmark;
+		name = "ProcessInfoRec.html: PATHDocument...";
+	};
+	E118552803F27D4A00050002 = {
+		fRef = E118553503F27D4A00050002;
+		glyphRangeLength = 2;
+		glyphRangeLocation = 4;
+		isa = PBXDocBookmark;
+		name = "carbon.html: ...";
+	};
+	E118552903F27D4A00050002 = {
+		fRef = E118554003F27D4A00050002;
+		glyphRangeLength = 4;
+		glyphRangeLocation = 0;
+		isa = PBXDocBookmark;
+		name = "processmanager.html: ...";
+	};
+	E118552A03F27D4A00050002 = {
+		fRef = E118553403F27D4A00050002;
+		glyphRangeLength = 0;
+		glyphRangeLocation = 0;
+		isa = PBXDocBookmark;
+	};
+	E118552B03F27D4A00050002 = {
+		fRef = E182C8F603DE817F00050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEEShared.m: 16";
+		rLen = 0;
+		rLoc = 357;
+		rType = 0;
+		vrLen = 1491;
+		vrLoc = 0;
+	};
+	E118552C03F27D4A00050002 = {
+		fRef = E14343B403DB4CF200050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEE.m: __PTRDIFF_TYPE__";
+		rLen = 0;
+		rLoc = 197;
+		rType = 0;
+		vrLen = 1599;
+		vrLoc = 0;
+	};
+	E118552D03F27D4A00050002 = {
+		fRef = F9A6986E03BE1DF000AA4DA5;
+		isa = PBXTextBookmark;
+		name = "APEMain.m: APEBundleMain";
+		rLen = 0;
+		rLoc = 3215;
+		rType = 0;
+		vrLen = 1824;
+		vrLoc = 1720;
+	};
+	E118552E03F27D4A00050002 = {
+		fRef = E11854F703F2709E00050002;
+		isa = PBXTextBookmark;
+		name = "CPS.h: kCPSUIElementAttr";
+		rLen = 17;
+		rLoc = 742;
+		rType = 0;
+		vrLen = 739;
+		vrLoc = 510;
+	};
+	E118552F03F27D4A00050002 = {
+		fRef = F9A6986E03BE1DF000AA4DA5;
+		isa = PBXTextBookmark;
+		name = "APEMain.m: APEBundleMain";
+		rLen = 0;
+		rLoc = 3208;
+		rType = 0;
+		vrLen = 1728;
+		vrLoc = 2080;
+	};
+	E118553003F27D4A00050002 = {
+		fRef = F56276C20379923401AA4DA5;
+		isa = PBXTextBookmark;
+		name = "APEInfo.rtfd: 131";
+		rLen = 0;
+		rLoc = 8185;
+		rType = 0;
+		vrLen = 1951;
+		vrLoc = 7002;
+	};
+	E118553103F27D4A00050002 = {
+		fRef = F9A6986E03BE1DF000AA4DA5;
+		isa = PBXTextBookmark;
+		name = "APEMain.m: APEBundleMain";
+		rLen = 0;
+		rLoc = 2217;
+		rType = 0;
+		vrLen = 1834;
+		vrLoc = 1604;
+	};
+	E118553303F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = MacTextEditor.h;
+		path = /System/Library/Frameworks/Carbon.framework/Versions/A/Frameworks/HIToolbox.framework/Versions/A/Headers/MacTextEditor.h;
+		refType = 0;
+	};
+	E118553403F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = index.html;
+		path = /Developer/Documentation/Carbon/oss/ProcessManager/Process_Manager/index.html;
+		refType = 0;
+	};
+	E118553503F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = carbon.html;
+		path = /Developer/Documentation/Carbon/carbon.html;
+		refType = 0;
+	};
+	E118553603F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = Processes.h;
+		path = /System/Library/Frameworks/ApplicationServices.framework/Versions/A/Frameworks/HIServices.framework/Versions/A/Headers/Processes.h;
+		refType = 0;
+	};
+	E118553703F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = ProcessInfoRec.html;
+		path = /Developer/Documentation/Carbon/oss/ProcessManager/Process_Manager/DataTypes/ProcessInfoRec.html;
+		refType = 0;
+	};
+	E118553803F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = CFString.h;
+		path = /System/Library/Frameworks/CoreFoundation.framework/Versions/A/Headers/CFString.h;
+		refType = 0;
+	};
+	E118553903F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = APETools.h;
+		path = /Library/Frameworks/ApplicationEnhancer.framework/Versions/A/Headers/APETools.h;
+		refType = 0;
+	};
+	E118553A03F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = CFBase.h;
+		path = /System/Library/Frameworks/CoreFoundation.framework/Versions/A/Headers/CFBase.h;
+		refType = 0;
+	};
+	E118553B03F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = CFDictionary.h;
+		path = /System/Library/Frameworks/CoreFoundation.framework/Versions/A/Headers/CFDictionary.h;
+		refType = 0;
+	};
+	E118553C03F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = Processes.h;
+		path = /System/Library/Frameworks/ApplicationServices.framework/Versions/A/Frameworks/HIServices.framework/Versions/A/Headers/Processes.h;
+		refType = 0;
+	};
+	E118553D03F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = Getting_Proc__Information.html;
+		path = /Developer/Documentation/Carbon/oss/ProcessManager/Process_Manager/Functions/Getting_Proc__Information.html;
+		refType = 0;
+	};
+	E118553E03F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = ProcessInfoRec.html;
+		path = /Developer/Documentation/Carbon/oss/ProcessManager/Process_Manager/DataTypes/ProcessInfoRec.html;
+		refType = 0;
+	};
+	E118553F03F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = carbon.html;
+		path = /Developer/Documentation/Carbon/carbon.html;
+		refType = 0;
+	};
+	E118554003F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = processmanager.html;
+		path = /Developer/Documentation/Carbon/oss/ProcessManager/processmanager.html;
+		refType = 0;
+	};
+	E118554103F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = Getting_Proc__Information.html;
+		path = /Developer/Documentation/Carbon/oss/ProcessManager/Process_Manager/Functions/Getting_Proc__Information.html;
+		refType = 0;
+	};
+	E118554203F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = processmanager.html;
+		path = /Developer/Documentation/Carbon/oss/ProcessManager/processmanager.html;
+		refType = 0;
+	};
+	E118554303F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = index.html;
+		path = /Developer/Documentation/Carbon/oss/ProcessManager/Process_Manager/index.html;
+		refType = 0;
+	};
+	E118554403F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = LaunchServices.h;
+		path = /System/Library/Frameworks/ApplicationServices.framework/Versions/A/Frameworks/LaunchServices.framework/Versions/A/Headers/LaunchServices.h;
+		refType = 0;
+	};
+	E118554503F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = Editing_Data.html;
+		path = /Developer/Documentation/Carbon/text/MultilingualTextEngine/Multilingual_Text_Engine/Functions/Editing_Data.html;
+		refType = 0;
+	};
+	E118554603F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = MacTextEditor.h;
+		path = /System/Library/Frameworks/Carbon.framework/Versions/A/Frameworks/HIToolbox.framework/Versions/A/Headers/MacTextEditor.h;
+		refType = 0;
+	};
+	E118554703F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = MacTypes.h;
+		path = /System/Library/Frameworks/CoreServices.framework/Versions/A/Frameworks/CarbonCore.framework/Versions/A/Headers/MacTypes.h;
+		refType = 0;
+	};
+	E118554803F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = CFArray.h;
+		path = /System/Library/Frameworks/CoreFoundation.framework/Versions/A/Headers/CFArray.h;
+		refType = 0;
+	};
+	E118554903F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = MacErrors.h;
+		path = /System/Library/Frameworks/CoreServices.framework/Versions/A/Frameworks/CarbonCore.framework/Versions/A/Headers/MacErrors.h;
+		refType = 0;
+	};
+	E118554A03F27D4A00050002 = {
+		isa = PBXFileReference;
+		name = APETools.h;
+		path = /Library/Frameworks/ApplicationEnhancer.framework/Versions/A/Headers/APETools.h;
+		refType = 0;
 	};
 	E120347A03EDEBC100000ABE = {
@@ -614,14 +1387,4 @@
 		vrLoc = 0;
 	};
-	E120347C03EDEBC100000ABE = {
-		fRef = E169DBA103E4EF5E00050002;
-		isa = PBXTextBookmark;
-		name = "ICeCoffEETextEdit.c: __VERSION__";
-		rLen = 0;
-		rLoc = 0;
-		rType = 0;
-		vrLen = 1370;
-		vrLoc = 0;
-	};
 	E120347D03EDEBC100000ABE = {
 		fRef = 089C165DFE840E0CC02AAC07;
@@ -629,5 +1392,5 @@
 		name = "English: 5";
 		rLen = 0;
-		rLoc = 147;
+		rLoc = 155;
 		rType = 0;
 		vrLen = 230;
@@ -643,14 +1406,4 @@
 		vrLen = 878;
 		vrLoc = 0;
-	};
-	E120347F03EDEBC100000ABE = {
-		fRef = E165AB3603E7A7FC00050002;
-		isa = PBXTextBookmark;
-		name = "ICeCoffEEActionMenu.c: ICCF_DoURLActionMenu";
-		rLen = 0;
-		rLoc = 8192;
-		rType = 0;
-		vrLen = 1275;
-		vrLoc = 8163;
 	};
 	E120348003EDEBC100000ABE = {
@@ -664,24 +1417,4 @@
 		vrLoc = 5828;
 	};
-	E120348103EDEBC100000ABE = {
-		fRef = E1BF15A503DBAA5600050002;
-		isa = PBXTextBookmark;
-		name = "ui.plist: 41";
-		rLen = 0;
-		rLoc = 1188;
-		rType = 0;
-		vrLen = 1038;
-		vrLoc = 285;
-	};
-	E120348203EDEBC100000ABE = {
-		fRef = F56276C20379923401AA4DA5;
-		isa = PBXTextBookmark;
-		name = "APEInfo.rtfd: 122";
-		rLen = 0;
-		rLoc = 7755;
-		rType = 0;
-		vrLen = 1000;
-		vrLoc = 12603;
-	};
 	E120348303EDEBC100000ABE = {
 		fRef = E182C8F603DE817F00050002;
@@ -709,5 +1442,5 @@
 		name = "English: 5";
 		rLen = 0;
-		rLoc = 147;
+		rLoc = 155;
 		rType = 0;
 		vrLen = 230;
@@ -749,5 +1482,5 @@
 		name = "ICeCoffEEActionMenu.c: mousePoint";
 		rLen = 0;
-		rLoc = 8192;
+		rLoc = 10386;
 		rType = 0;
 		vrLen = 1513;
@@ -759,5 +1492,5 @@
 		name = "English: 5";
 		rLen = 0;
-		rLoc = 147;
+		rLoc = 155;
 		rType = 0;
 		vrLen = 230;
@@ -779,5 +1512,5 @@
 		name = "ICeCoffEEActionMenu.c: ICCF_DoURLActionMenu";
 		rLen = 0;
-		rLoc = 8192;
+		rLoc = 10386;
 		rType = 0;
 		vrLen = 1275;
@@ -793,24 +1526,4 @@
 		vrLen = 1743;
 		vrLoc = 5828;
-	};
-	E120348E03EDEBC100000ABE = {
-		fRef = E1BF15A503DBAA5600050002;
-		isa = PBXTextBookmark;
-		name = "ui.plist: 41";
-		rLen = 0;
-		rLoc = 1188;
-		rType = 0;
-		vrLen = 1038;
-		vrLoc = 285;
-	};
-	E120348F03EDEBC100000ABE = {
-		fRef = F56276C20379923401AA4DA5;
-		isa = PBXTextBookmark;
-		name = "APEInfo.rtfd: 19";
-		rLen = 0;
-		rLoc = 614;
-		rType = 0;
-		vrLen = 907;
-		vrLoc = 0;
 	};
 	E1317A3503DF242100050002 = {
@@ -956,4 +1669,44 @@
 		vrLoc = 2804;
 	};
+	E157EE6C03F059E300050002 = {
+		fRef = F56276C20379923401AA4DA5;
+		isa = PBXTextBookmark;
+		name = "APEInfo.rtfd: 19";
+		rLen = 0;
+		rLoc = 614;
+		rType = 0;
+		vrLen = 907;
+		vrLoc = 0;
+	};
+	E157EE6D03F059E300050002 = {
+		fRef = E135625E03DC9FC200050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEEShared.h: ICCF_DEBUG";
+		rLen = 0;
+		rLoc = 283;
+		rType = 0;
+		vrLen = 1001;
+		vrLoc = 0;
+	};
+	E157EE6E03F059E300050002 = {
+		fRef = F56276C20379923401AA4DA5;
+		isa = PBXTextBookmark;
+		name = "APEInfo.rtfd: 246";
+		rLen = 0;
+		rLoc = 13453;
+		rType = 0;
+		vrLen = 1267;
+		vrLoc = 6919;
+	};
+	E157EE6F03F059E300050002 = {
+		fRef = F9A6986E03BE1DF000AA4DA5;
+		isa = PBXTextBookmark;
+		name = "APEMain.m: __VERSION__";
+		rLen = 0;
+		rLoc = 0;
+		rType = 0;
+		vrLen = 1146;
+		vrLoc = 0;
+	};
 	E165AB3B03E7B35000050002 = {
 		fRef = E165AB3603E7A7FC00050002;
@@ -961,5 +1714,5 @@
 		name = "ICeCoffEEAppMenu.c: 44";
 		rLen = 0;
-		rLoc = 7186;
+		rLoc = 9380;
 		rType = 0;
 		vrLen = 1734;
@@ -992,4 +1745,130 @@
 		path = /Applications/TextEdit.app;
 		refType = 0;
+	};
+	E166E9A903F2F8F100050002 = {
+		fRef = F56276C20379923401AA4DA5;
+		isa = PBXTextBookmark;
+		name = "APEInfo.rtfd: 121";
+		rLen = 0;
+		rLoc = 7846;
+		rType = 0;
+		vrLen = 1854;
+		vrLoc = 7003;
+	};
+	E166E9AA03F2F8F100050002 = {
+		fRef = E1BB268F03DB74B700050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEEMenuOnly.h: 1";
+		rLen = 0;
+		rLoc = 0;
+		rType = 0;
+		vrLen = 256;
+		vrLoc = 0;
+	};
+	E166E9AB03F2F8F100050002 = {
+		fRef = E1317B2F03DFC4DE00050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEETerminal.m: __VERSION__";
+		rLen = 0;
+		rLoc = 0;
+		rType = 0;
+		vrLen = 1881;
+		vrLoc = 44;
+	};
+	E166E9AC03F2F8F100050002 = {
+		isa = PBXTargetBookmark;
+		trg = F5CD5E9D02DAE2C901AA4DA5;
+		uiCtxt = {
+			TOCViewDetailVisibleRect = "{{0, 0}, {433, 644}}";
+			TOCViewExpandedItems = (
+				"com.apple.target-editor-pane.settings",
+				"com.apple.target-editor-pane.settings.simple",
+				"com.apple.target-editor-pane.info-plist",
+				"com.apple.target-editor-pane.info-plist.simple",
+				"com.apple.target-editor-pane.buildphases",
+			);
+			TOCViewMasterVisibleRect = "{{0, 0}, {170, 644}}";
+			TOCViewSelectedItems = (
+				"com.apple.target-editor-pane.info-plist.simple",
+			);
+		};
+	};
+	E166E9AD03F2F8F100050002 = {
+		fRef = E1BF15A503DBAA5600050002;
+		isa = PBXTextBookmark;
+		name = "ui.plist: 45";
+		rLen = 0;
+		rLoc = 1300;
+		rType = 0;
+		vrLen = 1327;
+		vrLoc = 0;
+	};
+	E166E9AE03F2F8F100050002 = {
+		fRef = F56276C20379923401AA4DA5;
+		isa = PBXTextBookmark;
+		name = "APEInfo.rtfd: 121";
+		rLen = 0;
+		rLoc = 7846;
+		rType = 0;
+		vrLen = 1854;
+		vrLoc = 7003;
+	};
+	E166E9AF03F2F8F100050002 = {
+		fRef = E1BB268F03DB74B700050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEEMenuOnly.h: 1";
+		rLen = 0;
+		rLoc = 0;
+		rType = 0;
+		vrLen = 256;
+		vrLoc = 0;
+	};
+	E166E9B003F2F8F100050002 = {
+		fRef = E1317B2F03DFC4DE00050002;
+		isa = PBXTextBookmark;
+		name = "ICeCoffEETerminal.m: __VERSION__";
+		rLen = 0;
+		rLoc = 0;
+		rType = 0;
+		vrLen = 1881;
+		vrLoc = 44;
+	};
+	E166E9B103F2F8F100050002 = {
+		isa = PBXTargetBookmark;
+		trg = F5CD5E9D02DAE2C901AA4DA5;
+		uiCtxt = {
+			TOCViewDetailVisibleRect = "{{0, 0}, {433, 644}}";
+			TOCViewExpandedItems = (
+				"com.apple.target-editor-pane.settings",
+				"com.apple.target-editor-pane.settings.simple",
+				"com.apple.target-editor-pane.info-plist",
+				"com.apple.target-editor-pane.info-plist.simple",
+				"com.apple.target-editor-pane.buildphases",
+			);
+			TOCViewMasterVisibleRect = "{{0, 0}, {170, 644}}";
+			TOCViewSelectedItems = (
+				"com.apple.target-editor-pane.info-plist.simple",
+			);
+		};
+	};
+	E166E9B203F2F8F100050002 = {
+		fRef = E1BF15A503DBAA5600050002;
+		isa = PBXTextBookmark;
+		name = "ui.plist: 45";
+		rLen = 0;
+		rLoc = 1300;
+		rType = 0;
+		vrLen = 1327;
+		vrLoc = 0;
+	};
+	E166E9B303F2F8F100050002 = {
+		fRef = 089C165DFE840E0CC02AAC07;
+		isa = PBXTextBookmark;
+		name = "English: 5";
+		rLen = 0;
+		rLoc = 155;
+		rType = 0;
+		vrLen = 238;
+		vrLoc = 0;
 	};
 	E169DBA603E4F62F00050002 = {
@@ -1057,5 +1936,5 @@
 		fileReference = E14343B403DB4CF200050002;
 		isa = PBXFileBreakpoint;
-		lineNumber = 148;
+		lineNumber = 145;
 		state = 1;
 	};
Index: trunk/ICeCoffEE/ICeCoffEE/ICeCoffEE APE.pbproj/project.pbxproj
===================================================================
--- trunk/ICeCoffEE/ICeCoffEE/ICeCoffEE APE.pbproj/project.pbxproj	(revision 82)
+++ trunk/ICeCoffEE/ICeCoffEE/ICeCoffEE APE.pbproj/project.pbxproj	(revision 88)
@@ -88,4 +88,5 @@
 			children = (
 				F9A6986E03BE1DF000AA4DA5,
+				E11854F703F2709E00050002,
 				E169DBA703E4F6A400050002,
 				E14343B303DB4CF200050002,
@@ -183,4 +184,16 @@
 //E13
 //E14
+		E11854F703F2709E00050002 = {
+			fileEncoding = 30;
+			isa = PBXFileReference;
+			path = CPS.h;
+			refType = 4;
+		};
+		E11854F903F270A700050002 = {
+			fileRef = E11854F703F2709E00050002;
+			isa = PBXBuildFile;
+			settings = {
+			};
+		};
 		E1317B2E03DFC4DE00050002 = {
 			fileEncoding = 30;
@@ -1214,4 +1227,5 @@
 				E13762D303EC636D00050002,
 				E18A7D2703ED3FA400050001,
+				E11854F903F270A700050002,
 			);
 			isa = PBXHeadersBuildPhase;
@@ -1321,5 +1335,5 @@
 	<string>ICCF</string>
 	<key>CFBundleVersion</key>
-	<string>1.3b3</string>
+	<string>1.3.1d1</string>
 </dict>
 </plist>
Index: trunk/ICeCoffEE/ICeCoffEE/ICeCoffEE.m
===================================================================
--- trunk/ICeCoffEE/ICeCoffEE/ICeCoffEE.m	(revision 82)
+++ trunk/ICeCoffEE/ICeCoffEE/ICeCoffEE.m	(revision 88)
@@ -4,7 +4,4 @@
 /* To do/think about:
 
-- Carbon contextual menu plugin which presents Services (yah!)
-  for both files and text
-- if it's not a URL, try using TextExtras' open list
 - TXNClick - MLTE has its own support in Jaguar and later, but it's lousy
 
Index: trunk/ICeCoffEE/ICeCoffEE/ICeCoffEEShared.h
===================================================================
--- trunk/ICeCoffEE/ICeCoffEE/ICeCoffEEShared.h	(revision 82)
+++ trunk/ICeCoffEE/ICeCoffEE/ICeCoffEEShared.h	(revision 88)
@@ -13,5 +13,5 @@
 #include <CoreFoundation/CoreFoundation.h>
 
-#define ICCF_DEBUG 0
+#define ICCF_DEBUG 1
 
 #if ICCF_DEBUG
Index: trunk/ICeCoffEE/ICeCoffEE/Installer components/ui/ui.plist
===================================================================
--- trunk/ICeCoffEE/ICeCoffEE/Installer components/ui/ui.plist	(revision 82)
+++ trunk/ICeCoffEE/ICeCoffEE/Installer components/ui/ui.plist	(revision 88)
@@ -43,5 +43,5 @@
 	<string>Preference Pane</string>
 	<key>ProductVersion</key>
-	<string>1.3</string>
+	<string>1.3.1d1</string>
 </dict>
 </plist>
Index: trunk/ICeCoffEE/ICeCoffEE/VERSION
===================================================================
--- trunk/ICeCoffEE/ICeCoffEE/VERSION	(revision 82)
+++ trunk/ICeCoffEE/ICeCoffEE/VERSION	(revision 88)
@@ -1,1 +1,1 @@
-1.3
+1.3.1d1

Index: trunk/ICeCoffEE/ICeCoffEE/ICeCoffEEActionMenu.c
===================================================================
--- trunk/ICeCoffEE/ICeCoffEE/ICeCoffEEActionMenu.c	(revision 82)
+++ trunk/ICeCoffEE/ICeCoffEE/ICeCoffEEActionMenu.c	(revision 88)
@@ -10,4 +10,5 @@
 #include "ICeCoffEEActionMenu.h"
 #include "ICeCoffEEConfig.h"
+#include "ICeCoffEEShared.h"
 #include "ICeCoffEEBookmarks.h"
 
@@ -32,15 +33,12 @@
     CFURLRef defaultAppURL; // URL of default app, set to NULL after added to menu
     CFMutableSetRef appPaths;
-    CFMutableDictionaryRef appNames; // keys: app display names (CFString), values: MenuItemIndex of matching item without path appended, or kICAppMenuItemHasPath if already appended (at least 2 items with this name exist)
+    CFMutableDictionaryRef appItemTitles; // keys: URLs; values: item titles (CFString)
+    CFMutableDictionaryRef appURLs; // keys: app display names (CFString), values: URL of item without path appended, or NULL if already appended (at least 2 items with this name exist)
     MenuRef menu;
 } icAppMenuContext;
 
-static OSStatus ICCF_AddAppToMenu(icAppMenuContext *ctx, CFURLRef appURL, MenuCommand menuCommand) {
+static OSStatus ICCF_AddAppItemTitle(icAppMenuContext *ctx, CFURLRef appURL) {
     CFStringRef appName = NULL, appItemTitle = NULL;
     CFBundleRef appBundle = NULL;
-    IconRef appIcon = NULL;
-    FSRef appRef;
-    SInt16 label;
-    MenuItemIndex menuItemIndex;
     OSStatus err = noErr;
 
@@ -48,23 +46,20 @@
     // only one entry for each path
     if (CFSetContainsValue(ctx->appPaths, appPath))
-        return noErr;
+        return dupFNErr;
     CFSetAddValue(ctx->appPaths, appPath);
-    
+
     if ( (err = LSCopyDisplayNameForURL(appURL, &appName)) != noErr)
         return err;
 
-    menuItemIndex = (long)CFDictionaryGetValue(ctx->appNames, appName);
-    if (menuItemIndex != 0) {
-        CFURLRef sameAppRef;
-        if (menuItemIndex != kICAppMenuItemHasPath &&
-            GetMenuItemRefCon(ctx->menu, menuItemIndex, (void *)&sameAppRef) == noErr) {
-            CFStringRef sameAppItemTitle = NULL;
-            if ( (err = CopyMenuItemTextAsCFString(ctx->menu, menuItemIndex, &sameAppItemTitle)) != noErr)
-                return err;
-            CFStringRef appItemTitleWithVersion = ICCF_NameWithLocation(sameAppItemTitle, sameAppRef);
-            SetMenuItemTextWithCFString(ctx->menu, menuItemIndex, appItemTitleWithVersion);
-            SAFE_RELEASE(appItemTitleWithVersion);
-            CFDictionarySetValue(ctx->appNames, appName, (void *)(long)kICAppMenuItemHasPath);
-        }
+    // if we encounter multiple applications with the same display name, add locations to the menu item titles to disambiguate them
+    CFURLRef sameAppURL;
+    Boolean shouldAppendLocation;
+    if ( (shouldAppendLocation = CFDictionaryGetValueIfPresent(ctx->appURLs, appName, (const void **)&sameAppURL)) && (CFTypeRef)sameAppURL != kCFNull) {
+        // this app is the second encountered with the same name; go back and fix the menu item title of the first app
+        CFStringRef sameAppItemTitle = CFDictionaryGetValue(ctx->appItemTitles, sameAppURL);
+        CFStringRef appItemTitleWithVersion = ICCF_NameWithLocation(sameAppItemTitle, sameAppURL);
+        CFDictionarySetValue(ctx->appItemTitles, sameAppURL, appItemTitleWithVersion);
+        SAFE_RELEASE(appItemTitleWithVersion);
+        CFDictionarySetValue(ctx->appURLs, appName, kCFNull);
     }
 
@@ -84,8 +79,10 @@
     }
 
-    if (menuItemIndex != 0) {
+    if (shouldAppendLocation) {
         CFStringRef appItemTitleWithVersion = ICCF_NameWithLocation(appItemTitle, appURL);
         CFRelease(appItemTitle);
         appItemTitle = appItemTitleWithVersion;
+    } else {
+        CFDictionarySetValue(ctx->appURLs, appName, appURL);
     }
 
@@ -95,18 +92,29 @@
         CFRelease(appItemTitle);
         appItemTitle = appItemTitleWithDefault;
-        ctx->defaultAppURL = NULL;
-    }
-
+        ctx->defaultAppURL = NULL; // mark as added
+    }
+
+    CFDictionarySetValue(ctx->appItemTitles, appURL, appItemTitle);
+    CFRelease(appItemTitle);
+
+    return noErr;
+}
+
+static OSStatus ICCF_AddTitledAppToMenu(icAppMenuContext *ctx, CFURLRef appURL, MenuCommand menuCommand) {
+    CFStringRef appItemTitle = NULL;
+    IconRef appIcon = NULL;
+    FSRef appFSR;
+    SInt16 label;
+    MenuItemIndex menuItemIndex;
+    OSStatus err = noErr;
+
+    appItemTitle = CFDictionaryGetValue(ctx->appItemTitles, appURL);
+    if (appItemTitle == NULL) return fnfErr;
+    
     err = AppendMenuItemTextWithCFString(ctx->menu, appItemTitle, 0, 0, &menuItemIndex);
-    CFRelease(appItemTitle);
     if (err != noErr) return err;
 
-    if (!CFDictionaryContainsKey(ctx->appNames, appName)) {
-        CFDictionarySetValue(ctx->appNames, appName, (void *)(long)menuItemIndex);
-        CFRelease(appName);
-    }
-
-    if (!CFURLGetFSRef(appURL, &appRef)) return paramErr;
-    err = GetIconRefFromFileInfo(&appRef, 0, NULL, kFSCatInfoNone, NULL, kIconServicesNormalUsageFlag, &appIcon, &label);
+    if (!CFURLGetFSRef(appURL, &appFSR)) return paramErr;
+    err = GetIconRefFromFileInfo(&appFSR, 0, NULL, kFSCatInfoNone, NULL, kIconServicesNormalUsageFlag, &appIcon, &label);
     if (err != noErr) return err;
 
@@ -119,4 +127,22 @@
 }
 
+static OSStatus ICCF_AddAppToMenu(icAppMenuContext *ctx, CFURLRef appURL, MenuCommand menuCommand) {
+    OSStatus err = ICCF_AddAppItemTitle(ctx, appURL);
+    switch (err) {
+        case noErr: break;
+        case dupFNErr: return noErr;
+        default: return err;
+    }
+    return ICCF_AddTitledAppToMenu(ctx, appURL, menuCommand);
+}    
+
+CFComparisonResult ICCF_CompareURLsByItemTitle(const void *url1, const void *url2, void *appItemTitles) {
+    CFStringRef appItemTitle1 = CFDictionaryGetValue((CFDictionaryRef)appItemTitles, (CFURLRef)url1);
+    CFStringRef appItemTitle2 = CFDictionaryGetValue((CFDictionaryRef)appItemTitles, (CFURLRef)url2);
+    return CFStringCompareWithOptions(appItemTitle1, appItemTitle2,
+                                      CFRangeMake(0, CFStringGetLength(appItemTitle1)),
+                                      kCFCompareCaseInsensitive | kCFCompareNumerically);
+}
+
 enum {
     kICURLActionOpenWith = 'OpnW',
@@ -127,5 +153,6 @@
     Handle h = NewHandle(0);
     CFURLRef url = NULL;
-    CFArrayRef appURLs = NULL; // matching app URLs
+    CFArrayRef appURLsUnsorted = NULL; // matching app URLs
+    CFMutableArrayRef appURLs = NULL; // matching app URLs sorted by item title
     CFArrayRef urlArray = NULL; // single-URL array
     icAppMenuContext ctx = {NULL, NULL, NULL, NULL};
@@ -140,18 +167,44 @@
                                      NULL)) == NULL) THROW_ERR(paramErr);
 
+    if ( (err = _LSCopyApplicationURLsForItemURL(url, kLSRolesAll, &appURLsUnsorted)) != noErr)
+        THROW_ERR(err);
+
     CFIndex appCount = 0;
-    if ( (err = _LSCopyApplicationURLsForItemURL(url, kLSRolesAll, &appURLs)) != noErr)
-        THROW_ERR(err);
-    
-    if (appURLs == NULL || (appCount = CFArrayGetCount(appURLs)) == 0)
+    if (appURLsUnsorted == NULL || (appCount = CFArrayGetCount(appURLsUnsorted)) == 0)
         THROW_ERR(kLSApplicationNotFoundErr);
 
+    if ( (appURLs = CFArrayCreateMutableCopy(NULL, appCount, appURLsUnsorted)) == NULL)
+        THROW_ERR(memFullErr);
+
     if ( (ctx.appPaths = CFSetCreateMutable(NULL, appCount, &kCFCopyStringSetCallBacks)) == NULL)
         THROW_ERR(memFullErr);
 
-    // values: index of single item with name; 0/NULL if no name; kICAppMenuItemHasPath if multiple items have name
-    if ( (ctx.appNames = CFDictionaryCreateMutable(NULL, appCount, &kCFCopyStringDictionaryKeyCallBacks, NULL)) == NULL)
-        THROW_ERR(memFullErr);
-
+    if ( (ctx.appItemTitles = CFDictionaryCreateMutable(NULL, appCount, &kCFTypeDictionaryKeyCallBacks, &kCFTypeDictionaryValueCallBacks)) == NULL)
+        THROW_ERR(memFullErr);
+
+    if ( (ctx.appURLs = CFDictionaryCreateMutable(NULL, appCount, &kCFCopyStringDictionaryKeyCallBacks, &kCFTypeDictionaryValueCallBacks)) == NULL)
+        THROW_ERR(memFullErr);
+
+    LSGetApplicationForURL(url, kLSRolesAll, NULL, &ctx.defaultAppURL);
+
+    CFIndex appIndex;
+    CFURLRef appURL;
+    for (appIndex = 0 ; appIndex < appCount ; appIndex++) {
+        appURL = CFArrayGetValueAtIndex(appURLs, appIndex);
+        err = ICCF_AddAppItemTitle(&ctx, appURL);
+        switch (err) {
+            case noErr: break;
+            case dupFNErr:
+                CFArrayRemoveValueAtIndex(appURLs, appIndex);
+                appIndex--;
+                appCount--;
+                break;
+            default:
+                THROW_ERR(err);
+        } 
+    }
+
+    CFArraySortValues(appURLs, CFRangeMake(0, appCount), ICCF_CompareURLsByItemTitle, ctx.appItemTitles);
+    
     if ( (err = CreateNewMenu(0, kMenuAttrExcludesMarkColumn, &ctx.menu)) != noErr)
         THROW_ERR(err);
@@ -164,13 +217,8 @@
         THROW_ERR(memFullErr);
 
-    LSGetApplicationForURL(url, kLSRolesAll, NULL, &ctx.defaultAppURL);
-
-    CFIndex appIndex;
-    CFURLRef appURL;
-
     for (appIndex = 0 ; appIndex < appCount ; appIndex++) {
         appURL = CFArrayGetValueAtIndex(appURLs, appIndex);
 
-        if ( (err = ICCF_AddAppToMenu(&ctx, appURL, kICURLActionOpenWith)) != noErr)
+        if ( (err = ICCF_AddTitledAppToMenu(&ctx, appURL, kICURLActionOpenWith)) != noErr)
             THROW_ERR(err);
     }
@@ -223,7 +271,9 @@
     SAFE_RELEASE(url);
     SAFE_RELEASE(urlArray);
+    SAFE_RELEASE(appURLsUnsorted);
     SAFE_RELEASE(appURLs);
-    SAFE_RELEASE(ctx.appNames);
     SAFE_RELEASE(ctx.appPaths);
+    SAFE_RELEASE(ctx.appItemTitles);
+    SAFE_RELEASE(ctx.appURLs);
     
     return err;